@@ -641,7 +641,7 @@ child_setup (gpointer user_data)
 	FrProcess *process = user_data;
 
 	if (process->priv->use_standard_locale)
-		putenv ("LC_MESSAGES=C");
+		putenv ("LC_ALL=C");
 
 	/* detach from the tty */
 
@@ -745,7 +745,7 @@ start_current_command (FrProcess *process)
 		int j;
 
 		if (process->priv->use_standard_locale)
-			g_print ("\tLC_MESSAGES=C\n");
+			g_print ("\tLC_ALL=C\n");
 
 		if (info->dir != NULL)
 			g_print ("\tcd %s\n", info->dir);
